==> esp8266-0.3.0.crate: esp8266-0.3.0/src/wdt/wdt_rst.rs <==
#[doc = "Register `WDT_RST` reader"]
pub struct R(crate::R<WDT_RST_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<WDT_RST_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<WDT_RST_SPEC>> for R {
    fn from(reader: crate::R<WDT_RST_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `WDT_RST` writer"]
pub struct W(crate::W<WDT_RST_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<WDT_RST_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<WDT_RST_SPEC>> for W {
    fn from(writer: crate::W<WDT_RST_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `Register` reader - "]
pub struct REGISTER_R(crate::FieldReader<u32, u32>);
impl REGISTER_R {
    pub(crate) fn new(bits: u32) -> Self {
        REGISTER_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for REGISTER_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `Register` writer - "]
pub struct REGISTER_W<'a> {
    w: &'a mut W,
}
impl<'a> REGISTER_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff_ffff) | ((value as u32) & 0xffff_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31"]
    #[inline(always)]
    pub fn register(&self) -> REGISTER_R {
        REGISTER_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
impl W {
    #[doc = "Bits 0:31"]
    #[inline(always)]
    pub fn register(&mut self) -> REGISTER_W {
        REGISTER_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "WDT_RST\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [wdt_rst](index.html) module"]
pub struct WDT_RST_SPEC;
impl crate::RegisterSpec for WDT_RST_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [wdt_rst::R](R) reader structure"]
impl crate::Readable for WDT_RST_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [wdt_rst::W](W) writer structure"]
impl crate::Writable for WDT_RST_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets WDT_RST to value 0"]
impl crate::Resettable for WDT_RST_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp8266-0.4.0.crate: esp8266-0.4.0/src/wdt/wdt_rst.rs <==
#[doc = "Register `WDT_RST` reader"]
pub struct R(crate::R<WDT_RST_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<WDT_RST_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<WDT_RST_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<WDT_RST_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `WDT_RST` writer"]
pub struct W(crate::W<WDT_RST_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<WDT_RST_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<WDT_RST_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<WDT_RST_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `Register` reader - "]
pub struct REGISTER_R(crate::FieldReader<u32, u32>);
impl REGISTER_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        REGISTER_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for REGISTER_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `Register` writer - "]
pub struct REGISTER_W<'a> {
    w: &'a mut W,
}
impl<'a> REGISTER_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = value as u32;
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31"]
    #[inline(always)]
    pub fn register(&self) -> REGISTER_R {
        REGISTER_R::new(self.bits as u32)
    }
}
impl W {
    #[doc = "Bits 0:31"]
    #[inline(always)]
    pub fn register(&mut self) -> REGISTER_W {
        REGISTER_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "WDT_RST\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [wdt_rst](index.html) module"]
pub struct WDT_RST_SPEC;
impl crate::RegisterSpec for WDT_RST_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [wdt_rst::R](R) reader structure"]
impl crate::Readable for WDT_RST_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [wdt_rst::W](W) writer structure"]
impl crate::Writable for WDT_RST_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets WDT_RST to value 0"]
impl crate::Resettable for WDT_RST_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
